'''
Created on Mar. 12, 2023

@author: wearo
'''
import unittest
from yopycalc.calc import Calc

# import sys
# for i in sys.path:
#     print(i)
    

class TestCalc(unittest.TestCase):        
    def setUp(self):
        self.calc = Calc(2, 3)

    def test_add_positive(self):
        # self.assertEqual(self.calc.add(), 5, "msg add Function is not working correctly")
        # self.assertEqual(self.calc.add(), 6, f"{__file__}: msg add Function is not working correctly")
        self.assertEqual(self.calc.add(), 5, f"{__file__}: msg add Function is not working correctly")

        # print("add Function works correctly")

def suite():
    """
        Gather all the tests from this module in a test suite.
    """
    suite = unittest.TestSuite()
    suite.addTest(TestCalc('test_add_positive')) 
    return suite

if __name__ == '__main__':
    runner = unittest.TextTestRunner(verbosity=2)
    runner.run(suite())


class Calc:
    def __init__(self, a, b):
        self.a = a
        self.b = b
    def add(self):
        return self.a + self.b
    
    def sub(self):
        return self.a - self.b
    
    def mul(self):
        return self.a * self.b
    
    def div(self):
        return self.a / self.b

def SayHello():
    print("sup world from srcmake")
    
if __name__ == '__main__':
    SayHello()




import setuptools

#Adding code for packaging
setuptools.setup(
    include_package_data=True, 
    name='yopycalc', 
    version='0.0.2.10', 
    description='yopycalc python module',
    url='https://github.com/ravindra-rao/setuptoolsdemo.git',
    author='yobro',
    author_email='contact@yobro.com',
    packages=setuptools.find_packages(),
    install_requires=['pandas', 'pytest'
    ], 
    long_description='yopycalc python module',
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
         "Operating System :: OS Independent",
    ],
)